@@ -1,17 +1,21 @@
-from typing import Optional, Union
+from typing import Union
 
+from myst.adapters.utils import UNSET
 from myst.models.timing import AbsoluteTiming, CronTiming, RelativeTiming, Timing
+from myst.models.types import OptionalParam
 from myst.openapi.models.absolute_timing_create import AbsoluteTimingCreate
 from myst.openapi.models.cron_timing_create import CronTimingCreate
 from myst.openapi.models.relative_timing_create import RelativeTimingCreate
 
 
 def to_timing_create(
-    timing: Optional[Timing],
-) -> Optional[Union[AbsoluteTimingCreate, RelativeTimingCreate, CronTimingCreate]]:
+    timing: OptionalParam[Timing],
+) -> OptionalParam[Union[AbsoluteTimingCreate, RelativeTimingCreate, CronTimingCreate]]:
     """Returns the appropriate OpenAPI model for the given timing, or None if timing is None."""
     if timing is None:
         return None
+    elif timing is UNSET:
+        return UNSET
     elif isinstance(timing, AbsoluteTiming):
         return AbsoluteTimingCreate(object="Timing", type="AbsoluteTiming", time=timing.time.to_iso_string())
     elif isinstance(timing, RelativeTiming):
