@@ -1,4 +1,4 @@
-from typing import Any, Optional
+from typing import Any, Dict, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -16,5 +16,5 @@ class ConnectorGet(base_model.BaseModel):
     title: str
     provider: str
     description: str
-    parameters_schema: Any
+    parameters_schema: Dict[str, Any]
     icon_url: Optional[str] = None
