@@ -1,8 +1,7 @@
 from typing import List, Optional
 
 from myst.models import base_model
-
-from ..models.validation_error import ValidationError
+from myst.openapi.models.validation_error import ValidationError
 
 
 class HTTPValidationError(base_model.BaseModel):
