@@ -4,9 +4,8 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.absolute_timing_create import AbsoluteTimingCreate
-from ..models.relative_timing_create import RelativeTimingCreate
+from myst.openapi.models.absolute_timing_create import AbsoluteTimingCreate
+from myst.openapi.models.relative_timing_create import RelativeTimingCreate
 
 
 class LayerUpdate(base_model.BaseModel):
