@@ -1,9 +1,10 @@
-from typing import Optional
+from typing import List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.job_error import JobError
 from myst.openapi.models.job_state import JobState
 
 
@@ -15,6 +16,7 @@ class NodeRunJobGet(base_model.BaseModel):
     create_time: str
     type: Literal["NodeRunJob"]
     node: str
+    errors: List[JobError]
     start_time: str
     end_time: str
     as_of_time: str
