@@ -1,4 +1,4 @@
-from typing import Any, List, Optional
+from typing import Any, Dict, List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -23,5 +23,5 @@ class SourceUpdate(base_model.BaseModel):
     project: Optional[str] = None
     deploy_status: Optional[DeployStatus] = None
     connector_uuid: Optional[str] = None
-    parameters: Optional[Any] = None
+    parameters: Optional[Dict[str, Any]] = None
     output_specs: Optional[List[TimeDatasetSpec]] = None
