@@ -1,4 +1,5 @@
 import json
+import warnings
 from typing import Any, Dict, Mapping, Optional
 
 import httpx
@@ -66,7 +67,14 @@ class BacktestResult(Resource):
             for predict_result in fold["predict_results"]:
                 for prediction in predict_result["predictions"]:
                     prediction_time_dataset = TimeDataset.parse_obj(prediction)
-                    prediction_pandas_object = prediction_time_dataset.flatten().to_pandas_object()
+                    # Disable an argument deprecated warning.
+                    with warnings.catch_warnings():
+                        warnings.filterwarnings(
+                            "ignore",
+                            category=FutureWarning,
+                            message="Argument `closed` is deprecated in favor of `inclusive`.",
+                        )
+                        prediction_pandas_object = prediction_time_dataset.flatten().to_pandas_object()
 
                     multi_index = pd.MultiIndex.from_product(
                         [prediction_pandas_object.index, [pd.Timestamp(predict_result["reference_time"])]],
@@ -78,7 +86,11 @@ class BacktestResult(Resource):
         prediction_pandas_object = pd.concat(prediction_pandas_objects)
 
         # Create the target data frame.
-        target_pandas_object = TimeDataset.parse_obj(result_data["targets"][0]).flatten().to_pandas_object()
+        with warnings.catch_warnings():
+            warnings.filterwarnings(
+                "ignore", category=FutureWarning, message="Argument `closed` is deprecated in favor of `inclusive`."
+            )
+            target_pandas_object = TimeDataset.parse_obj(result_data["targets"][0]).flatten().to_pandas_object()
 
         # Re-index the target data frame against the `time` index of the predictions, ensuring that we can make a
         # combined data frame with a single natural time index.
