@@ -3,10 +3,10 @@ from uuid import UUID
 
 from myst.client import get_client
 from myst.core.time.time_delta import TimeDelta
+from myst.models.enums import DeployStatus
 from myst.models.timing import TimeRangeBoundary
 from myst.models.types import AxisLabels, CoordinateLabels, ItemOrSlice, Shape
 from myst.openapi.api.projects.time_series import create_time_series
-from myst.openapi.models.deploy_status import DeployStatus
 from myst.openapi.models.time_series_create import TimeSeriesCreate
 from myst.openapi.models.time_series_get import TimeSeriesGet
 from myst.resources.resource import ShareableResource
